@@ -3,7 +3,7 @@
 // Purpose:    Accelerators and shortcuts
 // Part of:    4Pane
 // Author:     David Hart
-// Copyright:  (c) 2019 David Hart
+// Copyright:  (c) 2020 David Hart
 // Licence:    wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
@@ -229,7 +229,8 @@ const wxString DefaultMenuLabels[] = {
   _("Go to Symlink Target"),_("Go to Symlink Ultimate Target"),_("Edit"),_("New Separator"), _("Repeat Previous Program"), _("Navigate to opposite pane"), _("Navigate to adjacent pane"),
   _("Switch to the Panes"), _("Switch to the Terminal Emulator"), _("Switch to the Command-line"), _("Switch to the toolbar Textcontrol"), _("Switch to the previous window"), 
   _("Go to Previous Tab"), _("Go to Next Tab"), _("Paste as Director&y Template"), _("&First dot"), _("&Penultimate dot"), _("&Last dot"),
-  _("Mount over Ssh using ssh&fs"), _("Show &Previews"), _("C&ancel Paste"), _("Decimal-aware filename sort"), _("&Keep Modification-time when pasting files") };
+  _("Mount over Ssh using ssh&fs"), _("Show &Previews"), _("C&ancel Paste"), _("Decimal-aware filename sort"), _("&Keep Modification-time when pasting files"), 
+  _("Navigate up to higher directory"), _("Navigate back to previously visited directory"), _("Navigate forward to next visited directory")};
 
 int DefaultShortcutFlags[] = { wxACCEL_CTRL, wxACCEL_CTRL, wxACCEL_NORMAL, wxACCEL_SHIFT, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_CTRL,
       wxACCEL_ALT, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_CTRL, wxACCEL_CTRL+wxACCEL_SHIFT, wxACCEL_ALT+wxACCEL_SHIFT,
@@ -245,7 +246,8 @@ int DefaultShortcutFlags[] = { wxACCEL_CTRL, wxACCEL_CTRL, wxACCEL_NORMAL, wxACC
       wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_ALT, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_CTRL,
       wxACCEL_NORMAL, wxACCEL_NORMAL,wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_CTRL+wxACCEL_SHIFT, wxACCEL_CTRL+wxACCEL_SHIFT,
       wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL,
-      wxACCEL_CTRL+wxACCEL_SHIFT, wxACCEL_CTRL+wxACCEL_SHIFT, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_CTRL, wxACCEL_SHIFT, wxACCEL_NORMAL, wxACCEL_NORMAL };
+      wxACCEL_CTRL+wxACCEL_SHIFT, wxACCEL_CTRL+wxACCEL_SHIFT, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_CTRL, wxACCEL_SHIFT, wxACCEL_NORMAL, wxACCEL_NORMAL,
+      wxACCEL_CTRL+wxACCEL_SHIFT, wxACCEL_CTRL+wxACCEL_SHIFT, wxACCEL_CTRL+wxACCEL_SHIFT };
 
 int DefaultShortcutKeycode[] = { 'X', 'C', WXK_DELETE,WXK_DELETE,0, WXK_F2, 'D', // 7 entries
                               'P', 0, 0, 0, 'V', 'L', 'L',                       // 7
@@ -261,7 +263,8 @@ int DefaultShortcutKeycode[] = { 'X', 'C', WXK_DELETE,WXK_DELETE,0, WXK_F2, 'D',
                               0, 0, 0, WXK_F4, WXK_F1, 0, 0, 0, 'S',             // 9
                               0, 0, 0, 0, 0, 'O','A',                            // 7
                               0, 0, 0, 0, 0,                                     // 5
-                               ',', '.', 0, 0, 0, 0 , 0, 'P', WXK_ESCAPE, 0, 0 }; // 11
+                              ',', '.', 0, 0, 0, 0 , 0, 'P', WXK_ESCAPE, 0, 0,   // 11
+                              WXK_UP, WXK_LEFT, WXK_RIGHT };                     // 3
 
 const wxString DefaultMenuHelp[] = { 
   _("Cuts the current selection"), _("Copies the current selection"), _("Send to the Trashcan"), _("Kill, but may be resuscitatable"),_("Delete with extreme prejudice"), wxT(""), wxT(""),
@@ -279,7 +282,8 @@ _("Delete the currently-selected Tab"), _("Rename the currently-selected Tab"),
   wxT(""),wxT(""), wxT(""), wxT(""), wxT(""), wxT(""), 
   wxT(""), wxT(""), wxT(""), wxT(""), wxT(""),
   wxT(""), wxT(""), _("Paste only the directory structure from the clipboard"),_("An ext starts at first . in the filename"), _("An ext starts at last or last-but-one . in the filename"), _("An ext starts at last . in the filename"),
-  wxT(""), _("Show previews of image and text files"), _("Cancel the current process"), _("Should files like foo1, foo2 be in Decimal order"), _("Should a Moved or Pasted file keep its original modification time (as in 'cp -a')") };
+  wxT(""), _("Show previews of image and text files"), _("Cancel the current process"), _("Should files like foo1, foo2 be in Decimal order"), _("Should a Moved or Pasted file keep its original modification time (as in 'cp -a')"), 
+  wxT(""), wxT(""), wxT("") };
                               
 const size_t SHCUTno = sizeof(DefaultShortcutKeycode)/sizeof(int);
 
@@ -496,7 +500,6 @@ itemslistarray[4] = bmitems; itemslistcount[4] = sizeof(bmitems)/ptrsize; itemsl
 itemslistarray[6] = mountitems; itemslistcount[6] = sizeof(mountitems)/ptrsize; itemslistarray[7] = toolsitems; itemslistcount[7] = sizeof(toolsitems)/ptrsize;
 itemslistarray[8] = optionsitems; itemslistcount[8] = sizeof(optionsitems)/ptrsize; itemslistarray[9] = helpitems; itemslistcount[9] = sizeof(helpitems)/ptrsize;
 subitemslistarray[0] = columnitems; subitemslistcount[0] = sizeof(columnitems)/ptrsize; subitemslistarray[1] = loadtabitems; subitemslistcount[1] = sizeof(loadtabitems)/ptrsize;
-   
 
                                     // Make arrays for menus & for submenus
 const wxString menutitles[] = { _("&File"), _("&Edit"), _("&View"), _("&Tabs"), _("&Bookmarks"), _("&Archive"), _("&Mount"), _("Too&ls"), _("&Options"), _("&Help") };
@@ -578,7 +581,6 @@ AccelEntry* arrayentry = GetEntry(shortcutId);                // Find the correc
 
 wxString label = ConstructLabel(arrayentry, wxT(""));         // Construct & set the new label/accel
 menu->SetLabel(shortcutId, label);
-
 menu->SetHelpString(shortcutId, arrayentry->GetHelpstring()); // Set help too
 }
 
