@@ -98,9 +98,9 @@ bool ArchiveDialogBase::IsAnArchive(const wxString& filename, bool append/*=fals
 wxString ext = filename.AfterLast('.'); ext.MakeLower();    // See if the last .ext is relevant
 if (ext==wxT("tar") || ext==wxT("tgz") || ext==wxT("tbz2") || ext==wxT("tbz") || ext==wxT("lzma") || ext==wxT("tlz")
   || ext==wxT("a") || ext==wxT("ar") || ext==wxT("cpio") || ext==wxT("rpm") || ext==wxT("deb")
-  || (ext=="rar" && !append) // We can extract a .rar using the (free-ish) 'unrar' but can't append to one
-  || ext==wxT("7z")                                         // All 7z's are archives
-  || ext==wxT("zip") || ext==wxT("htb"))
+  || (ext=="rar" && !append) // We can extract a .rar using  'unar' or ( the free-ish) 'unrar' but can't append to one
+  || ext==wxT("7z") // All 7z's are archives
+  || ext==wxT("zip") || ext=="xpi" || ext==wxT("htb")) // xpi == zip
   return true;
   
 return (filename.Contains(wxT(".tar.")));                   // Otherwise see if there's a less-terminal tar ext
@@ -917,6 +917,22 @@ wxString binary; // This is debian-binary which, despite the name, is a text fil
 wxString overwrite;
 };
 
+ wxString LocateRARextractor() // Helper to find either unar or unrar
+{
+if (Configure::TestExistence("unar")) return "unar ";
+if (Configure::TestExistence("unrar")) return "unrar x ";
+
+return ""; 
+}
+
+wxString LocateRARverifier() // Helper to find either lsarr or unrar
+{
+if (Configure::TestExistence("lsar")) return "lsar -t ";
+if (Configure::TestExistence("unrar")) return "unrar t ";
+
+return ""; 
+}
+ 
 enum returntype ExtractArchiveDlg::GetCommand()
 {
 wxString command, decompresscommand;
@@ -1014,9 +1030,9 @@ switch(ztype)
                 command << wxT(" && ") << helper.GetData();
                 break;
                 }
-    case zt_rar: if (!Configure::TestExistence("unrar")) { wxMessageBox(_("Can't find unrar on your system..."), _("Oops"), wxOK, this); return cancel; }
-                command << wxString::Format("echo Extracting %s && ", archivename) << "(cd \\\"" << createindir
-                        << "\\\" && unrar x \\\"" << archive <<  "\\\")"; break;
+    case zt_rar:{ wxString derar = LocateRARextractor(); 
+                      if (derar.IsEmpty())  { wxMessageBox(_("Can't find unar either or unrar on your system..."), _("Oops"), wxOK, this); return cancel; }
+                      command << wxString::Format("echo Extracting %s && (cd \\\"%s\\\" && %s  \\\"%s\\\" )", archivename, createindir, derar, archive); break;}
 
     default:    wxMessageDialog dialog(this, _("Can't find a valid archive to extract.\nTry again?"), wxT(""), wxYES_NO | wxICON_QUESTION);
                 if (dialog.ShowModal() == wxID_YES)  return retry; else return cancel;
@@ -1165,8 +1181,10 @@ switch(m_parent->Categorise(archivefilepath))
     case zt_ar:
             command << wxString::Format(wxT("echo Verifying %s && "), archivename.c_str()) << wxT("ar tv \\\"") << archivefilepath <<  wxT("\\\""); break;
     case zt_rar:
-            if (!Configure::TestExistence("unrar")) { wxMessageBox(_("Can't find unrar on your system..."), _("Oops"), wxOK, this); return cancel; }
-            command << wxString::Format("echo Verifying %s && ", archivename.c_str()) << "unrar t \\\"" << archivefilepath <<  "\\\""; break;
+                      { wxString verifyrar = LocateRARverifier(); 
+                      if (verifyrar.IsEmpty()) { wxMessageBox(_("Can't find either lsar or unrar on your system..."), _("Oops"), wxOK, this); return cancel; }
+                      command << wxString::Format("echo Verifying %s && %s ", archivename, verifyrar) << "\\\"" << archivefilepath <<  "\\\""; break;
+                      }
     case zt_deb:
             command << wxString::Format(wxT("echo Verifying %s && "), archivename.c_str())
                     << wxT("ar p \\\"") << archivefilepath <<  wxT("\\\" control.tar.gz | tar -ztv && ")
