@@ -75,7 +75,6 @@ class NoConfigWizard  :  public wxWizard
 {
 public:
 NoConfigWizard(wxWindow* parent, int id, const wxString& title, const wxString& configFPath);
-wxCheckBox* shortcut;        // So the user can ask for a desktop shortcut (not) to be provided if there isn't one already
 FirstPage* Page1;
 SecondPage* Page2;
 ThirdPage* Page3;
@@ -85,7 +84,7 @@ void OnPageChanged(wxWizardEvent& event) { ((MyWizardPage*)event.GetPage())->OnP
 void OnEventSetFocusNext(wxCommandEvent& event) { if (m_Next) m_Next->SetFocus(); } // Set focus to the 'Next' button
 void OnButton(wxCommandEvent& event);
 
-wxString m_configFPath; // Normally ~/.4Pane, but not if the instance was invoked with the -c option
+wxString m_configFPath; // Normally ~/.config/4Pane/.4Pane, but not if the instance was invoked with the -c option
 wxButton* m_Next;
 private:
 DECLARE_EVENT_TABLE()
