@@ -3,7 +3,7 @@
 // Purpose:    Mounting etc of Devices
 // Part of:    4Pane
 // Author:     David Hart
-// Copyright:  (c) 2016 David Hart
+// Copyright:  (c) 2020 David Hart
 // Licence:    GPL v3
 /////////////////////////////////////////////////////////////////////////////
 #ifndef DEVICESH
@@ -49,7 +49,6 @@ class DeviceBitmapButton  :  public MyBitmapButton
 {
 public:
 DeviceBitmapButton(enum devicecategory which);
-DeviceBitmapButton();
 
 void OnEndDrag();                                // Used when DragnDrop deposits on one of our toolbar buttons
 static void SaveDefaults(wxConfigBase* config=NULL);
@@ -90,6 +89,28 @@ private:
 DECLARE_EVENT_TABLE()
 };
 
+
+class GvfsBitmapButton : public MyBitmapButton
+{
+public:
+GvfsBitmapButton(wxWindow* parent, const wxString& mntpt );
+
+wxString GetOriginalMountpt() { return m_originalMountpt; }
+wxString GetOriginalSelection() { return m_originalSelection; }
+const wxString GetMountpt() { return m_mountpt; }
+
+protected:
+void OnButtonClick(wxCommandEvent& event);
+void OnUnMount(wxCommandEvent& event);
+void OnRightButtonClick(wxContextMenuEvent& event);
+
+wxString m_buttonname;
+const wxString m_mountpt;
+wxString m_originalMountpt, m_originalSelection, m_originalFileviewSelection;
+DECLARE_EVENT_TABLE()
+};
+
+
 struct DevicesStruct   // Holds data for a device
   { wxString devicenode;          // Holds eg /dev/fd0 or /dev/sda, even in the case  of multipartition devices  eg /dev/sda1, sda2 etc  ie major number only
     int idVendor; int idProduct;  // For usb etc devices, hold the (hopefully unique) ids of a device 
@@ -148,9 +169,18 @@ struct NetworkStruct   // Holds NFS or samba info
     NetworkStruct() : readonly(false) {}
   };
 
+struct GvfsStruct   // Holds gphoto2: cdda: mtp: gvfs 'mounts'
+  { const wxString mountpt; // e.g. /run/user/1000/gvfs/cdda:host=sr0 (or ~/.gvfs/cdda:host=sr0)
+    const wxString type;    // currently gphoto2: mtp: or cdda:
+    GvfsBitmapButton* button; // The & of the corresponding button is stored here, so that we can find it within the device sizer for removal
+    
+    GvfsStruct(const wxString& mpt, GvfsBitmapButton* btn) : mountpt(mpt), type(mountpt.AfterLast(wxFILE_SEP_PATH).BeforeFirst(':') + ':'), button(btn) {}
+  };
+
 WX_DEFINE_ARRAY(DevicesStruct*, ArrayofDeviceStructs);      // Define the arrays we'll be using
 WX_DEFINE_ARRAY(PartitionStruct*, ArrayofPartitionStructs);
 WX_DEFINE_ARRAY(NetworkStruct*, ArrayofNetworkStructs);
+WX_DEFINE_ARRAY(GvfsStruct*, ArrayofGvfsStructs);
 
 struct DevInfo    // Used by DeviceInfo to store info about a device
 {
@@ -189,6 +219,29 @@ void LoadDefaults();
 ArrayofDevInfoStructs* devinfo;
 };
 
+class GvfsInfo  // Holds & provides data about gvfs mounts e.g. gphoto2:
+{
+public:
+GvfsInfo() { m_gvfsmounts = new ArrayofGvfsStructs; }
+~GvfsInfo() { for (int n = (int)m_gvfsmounts->GetCount();  n > 0; --n )  {  GvfsStruct* item = m_gvfsmounts->Item(n-1); delete item; } delete m_gvfsmounts; }
+
+wxString GetMountpt(size_t index) { if (index >= m_gvfsmounts->GetCount()) return ""; return m_gvfsmounts->Item(index)->mountpt; }
+wxString GetType(size_t index) { if (index >= m_gvfsmounts->GetCount()) return ""; return m_gvfsmounts->Item(index)->type; }
+GvfsBitmapButton* GetButton(size_t index) { if (index >= m_gvfsmounts->GetCount()) return NULL; return m_gvfsmounts->Item(index)->button; }
+size_t GetCount() { return m_gvfsmounts->GetCount(); }
+void Add(const wxString& mountpt, GvfsBitmapButton* button) { GvfsStruct* gvfsstruct = new struct GvfsStruct(mountpt, button); m_gvfsmounts->Add(gvfsstruct); }
+void Remove(size_t i) { wxCHECK_RET(i < m_gvfsmounts->GetCount(), "Incorrect index"); delete m_gvfsmounts->Item(i); m_gvfsmounts->RemoveAt(i); }
+int Find(const wxString& MountptToFind) 
+  { if (MountptToFind.IsEmpty()) return (wxNOT_FOUND-1); 
+    for (int n=0; n < GetCount(); ++n)
+      { if (GetMountpt(n) == MountptToFind) return n; }
+    return wxNOT_FOUND; 
+  }
+
+protected:
+ArrayofGvfsStructs* m_gvfsmounts;
+};
+
 class DeviceAndMountManager;
 
 class DeviceManager                              // Class to manipulate device data & things like its mount & button status
@@ -275,6 +328,7 @@ void SearchMtabForStandardMounts( wxString& device, wxArrayString& mountpts);  /
 #endif
 
 DeviceManager* deviceman;                         // Class that does the dirty work with devices
+GvfsInfo* m_gvfsinfo;                             // Detects & displays gvfs mounts
 ArrayofPartitionStructs* PartitionArray;          // To hold partitions, mountpt, status
 wxString DefaultUsbDevicename;                    // If there's ever an unattached device to configure, use this as its /dev location
 MyUsbDevicesTimer* usbtimer;
@@ -296,6 +350,7 @@ void FindMountedImages();                                     // Add mounted iso
 bool MkDir(wxString& mountpt);                                // Make a dir onto which to mount
 bool WeCanUseSmbmnt(wxString& mountpt, bool TestUmount = false);  // Do we have enough kudos to (u)mount with smb
                               // These are used in automounting distros
+void CheckForGioAutomountedDevices();                         // Check for devices e.g. cds, mounted by GIO inside /run/user/
 void CheckForAutomountedDevices();                            // Check for any other auto-mountables eg USB devices, in automounting distros
 void CheckForHALAutomountedDevices();                         // Ditto in Hal-automounting distros
 int MatchHALInfoToDevicestruct(DevicesStruct* tempstruct, int idVendor, int idProduct, wxString& vendor, wxString& model, wxString& devnode);  // See if this devicestruct matches the host/model data from HAL
