@@ -3,7 +3,7 @@
 // Purpose:    Checks/manages Duplication & Renaming
 // Part of:    4Pane
 // Author:     David Hart
-// Copyright:  (c) 2016 David Hart
+// Copyright:  (c) 2019 David Hart
 // Licence:    GPL v3
 /////////////////////////////////////////////////////////////////////////////
 
@@ -429,6 +429,12 @@ switch(dialogversion)                  // If dialogversion==0 or 2, use polite d
                     wxString str(_("The current file was modified on ")); CurrentStatic->SetLabel(str + desttimestr);
                     str = _("The incoming file was modified on "); IncomingStatic->SetLabel(str + intimestr);
                   }
+#if wxVERSION_NUMBER >= 3100
+                  // Previously this was unnecessary; the statictexts knew their own size. However since wx3.1 they don't; perhaps because of the ellipsize feature
+                  NameStatic->SetMinSize(NameStatic->GetSizeFromTextSize(NameStatic->GetTextExtent(namestr)));
+                  CurrentStatic->SetMinSize(CurrentStatic->GetSizeFromTextSize(CurrentStatic->GetTextExtent(CurrentStatic->GetLabel())));
+                  IncomingStatic->SetMinSize(IncomingStatic->GetSizeFromTextSize(IncomingStatic->GetTextExtent(IncomingStatic->GetLabel())));
+#endif
 
                 mydlg.GetSizer()->Fit(&mydlg);
                 mydlg.GetSizer()->Layout();     // Needed from 2.9, otherwise the statics don't recentre
