@@ -3,7 +3,7 @@
 // Purpose:    Extern declarations, enums
 // Part of:    4Pane
 // Author:     David Hart
-// Copyright:  (c) 2016 David Hart
+// Copyright:  (c) 2020 David Hart
 // Licence:    GPL v3
 /////////////////////////////////////////////////////////////////////////////
 #ifndef EXTERNSH
@@ -333,6 +333,10 @@ enum                  //  menuitem IDs
   
   SHCUT_RETAIN_MTIME_ON_PASTE, // When Moving/Pasting, try to leave the modification time ISQ (like cp -a)
 
+  SHCUT_NAVIGATE_DIR_UP,  // Directory navigation: the dirview toolbar Up/Left/Right arrows
+  SHCUT_NAVIGATE_DIR_PREVIOUS,
+  SHCUT_NAVIGATE_DIR_NEXT,
+
 
   // *****
 
@@ -403,7 +407,7 @@ enum deviceID      //  to do with toolbar bitmap-buttons
 
 enum whichcan { delcan, trashcan, tempfilecan };  // Deals with deleted/trash/tempfile dirs
 
-enum devicecategory { harddiskcat = 0, floppycat, cdromcat, cdrcat, usbpencat, usbmemcat, usbmultcardcat, usbharddrivecat, unknowncat, rubbish=-1 };
+enum devicecategory { harddiskcat = 0, floppycat, cdromcat, cdrcat, usbpencat, usbmemcat, usbmultcardcat, usbharddrivecat, unknowncat, cddacat, gphoto2cat, mtpcat, rubbish=-1 };
   
 enum treerooticon { ordinary = 0, floppytype, cdtype, usbtype, twaddle };  // Which icons to use for the treectrl root image: folder, floppy etc.  All the cd-types share an icon
 
