@@ -3,7 +3,7 @@
 // Purpose:     Dir-view
 // Part of:     4Pane
 // Author:      David Hart
-// Copyright:   (c) 2016 David Hart
+// Copyright:   (c) 2020 David Hart
 // Licence:     GPL v3
 /////////////////////////////////////////////////////////////////////////////
 #ifndef MYDIRSH
@@ -124,7 +124,7 @@ DirGenericDirCtrl(wxWindow* parent, const wxWindowID id, const wxString& START_D
                                    long style = wxSUNKEN_BORDER, bool full_tree=false, const wxString& name = wxT("DirGenericDirCtrl"));
               
 ~DirGenericDirCtrl();
-          
+
 void CreateToolbar();
 void OnFullTree(wxCommandEvent& event);         // Toggles Fulltree button
 void OnDirUp(wxCommandEvent& event);            // From toolbar Up button
@@ -157,6 +157,8 @@ NavigationManager& GetNavigationManager() { return m_NavigationManager; }
 
 protected: 
 void CreateAcceleratorTable();
+void OnIdle(wxIdleEvent& event);   
+void DoScrolling();
 
 NavigationManager m_NavigationManager;
 MyDropdownButton* MenuOpenButton1;                // The dir-navigation buttons sidebars (those things that allow you to choose any of the previous dirs) 
