@@ -3,7 +3,7 @@
 // Purpose:    File-view
 // Part of:    4Pane
 // Author:     David Hart
-// Copyright:  (c) 2019 David Hart
+// Copyright:  (c) 2020 David Hart
 // Licence:    GPL v3
 /////////////////////////////////////////////////////////////////////////////
 
@@ -297,7 +297,7 @@ int AccelEntries[] =
           SHCUT_SWITCH_FOCUS_COMMANDLINE, SHCUT_SWITCH_FOCUS_TOOLBARTEXT, SHCUT_SWITCH_TO_PREVIOUS_WINDOW,
           SHCUT_PREVIOUS_TAB,SHCUT_NEXT_TAB,
           SHCUT_EXT_FIRSTDOT, SHCUT_EXT_MIDDOT, SHCUT_EXT_LASTDOT,
-          SHCUT_DECIMALAWARE_SORT
+          SHCUT_DECIMALAWARE_SORT, SHCUT_NAVIGATE_DIR_UP, SHCUT_NAVIGATE_DIR_PREVIOUS, SHCUT_NAVIGATE_DIR_NEXT
         };
 const size_t shortcutNo = sizeof(AccelEntries)/sizeof(int);
 MyFrame::mainframe->AccelList->CreateAcceleratorTable(this, AccelEntries,  shortcutNo);
@@ -1628,6 +1628,14 @@ Recursebox->Show(queryrecurse);                         // Don't show the Apply
 ((wxStaticText*)dlg.FindWindow(wxT("OwnerID")))->SetLabel(wxString::Format(wxT("%u"), stat->OwnerID()));
 ((wxStaticText*)dlg.FindWindow(wxT("GroupID")))->SetLabel(wxString::Format(wxT("%u"), stat->GroupID()));
 
+wxTextCtrl* filecommandoutput = dynamic_cast<wxTextCtrl*>(dlg.FindWindow("FileCommandOutput"));
+if (filecommandoutput)
+ { wxArrayString output, errors;
+   long ans = wxExecute("sh -c \"(cd " + stat->GetPath() + " && file ./" + stat->GetFilename() + ')' + '\"', output,errors); // Do 'file ./filename' so the output isn't spammed by long paths
+   if (ans == 0 && !output.IsEmpty())
+      filecommandoutput->SetValue(output.Item(0));
+ }
+
 bool ClusterWasNeeded = UnRedoManager::StartClusterIfNeeded();  // Start a new UnRedoManager cluster. Doing it here catches both rename & changesymlinktarget
 do
   { HelpContext = HCproperties;
