@@ -3,7 +3,7 @@
 // Purpose:     App, Frame and Layout stuff
 // Part of:     4Pane
 // Author:      David Hart
-// Copyright:   (c) 2016 David Hart
+// Copyright:   (c) 2020 David Hart
 // Licence:     GPL v3
 /////////////////////////////////////////////////////////////////////////////
 #ifndef MYFRAMEH
@@ -347,7 +347,7 @@ wxBoxSizer* FixedDevicesSizer;
 
 void OnUpdateTrees(const wxString& path, const wxArrayInt& IDs, const wxString& newstartdir = wxT(""), bool FromArcStream = false);  // Tells all panes that branch <path> needs updating.  IDs hold which panes MUST be done
 void UpdateTrees();                                // At the end of a cluster of actions, tells all treectrls actually to do the updating they've stored
-void OnUnmountDevice(wxString& path);              // When we've successfully umounted eg a floppy, reset treectrl(s) displaying it to HOME
+void OnUnmountDevice(wxString& path, const wxString& replacement="");  // When we've successfully umounted eg a floppy, reset treectrl(s) displaying it to 'replacement' or HOME or...
 
 void SetSensibleFocus();                           // Ensures that keyboard focus is held by a valid window, usually the active pane
 MyGenericDirCtrl* GetActivePane();                 // Returns the most-recently-active pane in the visible tab
