@@ -5,7 +5,7 @@
 //              wxFile application, modified by Harm van der Heijden.
 //              Further modified for Windows. Further modified for 4Pane
 // Author:      Robert Roebling, Harm van der Heijden, Julian Smart et al
-// Modified by: David Hart 2016
+// Modified by: David Hart 2003-20
 // Created:     21/3/2000
 // Copyright:   (c) Robert Roebling, Harm van der Heijden, Julian Smart. Alterations (c) David Hart
 // Licence:     wxWindows licence
@@ -204,6 +204,7 @@ void  TakeYourPartners(MyGenericDirCtrl *otherside)  // //  Set the pointer to t
 void OnTreeSelected(wxTreeEvent &event);      // //
 void OnTreeItemDClicked(wxTreeEvent &event);  // //
   void OnOutsideSelect(wxString& path, bool CheckDevices=true); // // Used to redo Ctrl from outside, eg the floppy-button clicked (& if called from Mount, don't remount again!)
+  wxString GetPathIfRelevant(); // // Helper function used to get selection to pass to NavigationManager
   void RefreshTree(const wxString& path, bool CheckDevices=true, bool RetainSelection=true); // // Refreshes the display to show any outside changes (or following a change of rootitem via OnOutsideSelect)
   void OnRefreshTree(wxCommandEvent& event);                    // // From Context menu or F5. Needed to provide the parameter for RefreshTree
 void DisplaySelectionInTBTextCtrl(const wxString& selection);   // // 
@@ -256,6 +257,7 @@ bool NoVisibleItems;                                          // // Flags whethe
 // //  virtual int GetFilterIndex() const { return m_currentFilter; }
 // //   virtual void SetFilterIndex(int n);
 
+    MyTreeCtrl* GetMyTreeCtrl() const { return m_treeCtrl; }
     virtual wxTreeCtrl* GetTreeCtrl() const { return (wxTreeCtrl*)m_treeCtrl; }        // // Altered as m_treeCtrl is now a MyTreeCtrl
 // //    virtual wxDirFilterListCtrl* GetFilterListCtrl() const { return m_filterListCtrl; }
 
@@ -297,7 +299,6 @@ void SetTreePrefs();      // //  Adjusts the Tree width parameters according to
 void DoDisplaySelectionInTBTextCtrl(wxNotifyEvent& event);       // // Does so on receiving a MyUpdateToolbartextEvent from DisplaySelectionInTBTextCtrl
 
 MyGenericDirCtrl* ParentControl;    // //  Pointer to the derived CONTROL, eg DirGenericDirCtrl, not the splitter window or tab panel
-wxString GetPathIfRelevant(); // // Helper function used to get selection to pass to NavigationManager
 
 #if defined(__LINUX__) && defined(__WXGTK__)
 	void OnFileWatcherEvent(wxFileSystemWatcherEvent& event);
