@@ -1336,7 +1336,27 @@ void MyTreeCtrl::PaintLevel(wxGenericTreeItem *item, wxDC &dc, int level, int &y
                     dc.DrawLine(3, y_mid, x - 5, y_mid);
                 dc.DrawLine(x + 5, y_mid, x + m_spacing, y_mid);
             }
+#if wxVERSION_NUMBER > 3105
+            if ( m_imagesButtons.HasImages() )
+            {
+                // draw the image button here
+                int image_h = 0,  image_w = 0;
+                int image = item->IsExpanded() ? wxTreeItemIcon_Expanded
+                                               : wxTreeItemIcon_Normal;
+                if ( item->IsSelected() )
+                    image += wxTreeItemIcon_Selected - wxTreeItemIcon_Normal;
 
+                wxImageList* const
+                    imageListButtons = m_imagesButtons.GetImageList();
+                imageListButtons->GetSize(image, image_w, image_h);
+                int xx = x - image_w/2;
+                int yy = y_mid - image_h/2;
+
+                wxDCClipper clip(dc, xx, yy, image_w, image_h);
+                imageListButtons->Draw(image, dc, xx, yy,
+                                         wxIMAGELIST_DRAW_TRANSPARENT);
+            }
+#else // !wxVERSION_NUMBER > 3105
             if (m_imageListButtons != NULL)
             {
                 // draw the image button here
@@ -1352,9 +1372,10 @@ void MyTreeCtrl::PaintLevel(wxGenericTreeItem *item, wxDC &dc, int level, int &y
                                          wxIMAGELIST_DRAW_TRANSPARENT);
                 dc.DestroyClippingRegion();
             }
-
+#endif
     }
   }
+
            else // no custom buttons
             {
                 static const int wImage = 9;
@@ -1495,15 +1516,17 @@ if (headerwindow->IsHidden(i)) continue;                                  // //
       image = NO_IMAGE;  // //item->GetImage(i);
       }
   
-  if(image != NO_IMAGE) 
-   {
-      if(m_imageListNormal) {
-    m_imageListNormal->GetSize(image, image_w, image_h);
-    image_w += 4;
-                          }
-      else {
-    image = NO_IMAGE;
-          }
+    if (image != NO_IMAGE) 
+     {
+#if wxVERSION_NUMBER > 3105
+      if (GetImageList()) {
+          GetImageList()->GetSize(image, image_w, image_h);
+#else
+      if (m_imageListNormal) {
+        m_imageListNormal->GetSize(image, image_w, image_h);
+#endif // wxVERSION_NUMBER > 3105
+        image_w += 4;
+      } else { image = NO_IMAGE;  }
    }
 
   // honor text alignment
@@ -1581,8 +1604,12 @@ if (headerwindow->IsHidden(i)) continue;                                  // //
           item->GetY() + extraH, clip_width,
           total_h);
 
-  if(image != NO_IMAGE) {
+  if (image != NO_IMAGE) {
+#if wxVERSION_NUMBER > 3105
+      GetImageList()->Draw(image, dc, image_x,
+#else
       m_imageListNormal->Draw(image, dc, image_x,
+#endif
              item->GetY() +((total_h > image_h)?
                 ((total_h-image_h)/2):0),
              wxIMAGELIST_DRAW_TRANSPARENT);
