@@ -378,7 +378,7 @@ class TerminalEm : public TextCtrlBase    // Derive from this so that (in gtk2)
 public:
 TerminalEm(){};
 TerminalEm(wxWindow* parent, wxWindowID id, const wxString& value = wxT(""), bool multline = true,  const wxPoint& pos = wxDefaultPosition,
-           const wxSize& size = wxDefaultSize, long style = 0, const wxValidator& validator = wxDefaultValidator,  const wxString& name = wxT("TerminalEm"))
+           const wxSize& size = wxDefaultSize, long style = wxTE_PROCESS_ENTER, const wxValidator& validator = wxDefaultValidator,  const wxString& name = wxT("TerminalEm"))
             :     TextCtrlBase(parent, id, value, multline, pos, size, style, validator, name), multiline(multline) { Init(); }
 ~TerminalEm();
 void Init();                                               // Do the ctor work here, as otherwise wouldn't be done under xrc
@@ -426,13 +426,17 @@ MyPipedProcess* m_running;
 ExecInPty* m_ExecInPty;
 wxTimer m_timerIdleWakeUp;                // The idle event wake up timer
 
+wxString GetCurrentPrompt() const { return m_CurrentPrompt; }
+int GetCommandStart() const { return m_CommandStart; }
+
 static wxArrayString History;             // We want only 1 history, shared between instances
 static int HistoryCount;
 static bool historyloaded;                //   & we want only to load it once!
 static int QuerySuperuser;                // Helps determine the command prompt.  See Init()
-int CommandStart;
+int m_CommandStart;
 wxString UnenteredCommand;                // This is for an entry that has been typed in, but before a <CR> the command-history is invoked
 wxString PromptFormat;                    // User-definable prompt appearance definition
+wxString m_CurrentPrompt;                 // The current prompt string
 TerminalEm* display;                      // Where to output.  If multiline, it's 'this', otherwise it's set by SetOutput()
 wxString originaldir;
 bool busy;                                // Set by OnKey when it's processing a command to prevent an undesirable cd
